<?php
namespace wcf\action;
use wcf\data\user\UserAction;
use wcf\system\exception\IllegalLinkException;
use wcf\system\request\LinkHandler;
use wcf\system\WCF;
use wcf\util\HeaderUtil;

/**
 * Performs the chosen action, if a user declines the terms of use.
 *
 * @author	Sascha Greuel <sascha@softcreatr.de>
 * @copyright	2013-2014 Sascha Greuel
 * @license	Creative Commons Attribution-NoDerivatives <http://creativecommons.org/licenses/by-nd/4.0/legalcode>
 * @package	be.bastelstu.sascha.termsofuse
 * @subpackage	action
 * @category	Community Framework
 */
class TermsOfUseDeclineAction extends AbstractAction {
	/**
	 * @see	\wcf\page\AbstractPage::$neededModules
	 */
	public $neededModules = array('MODULE_USER_TERMS_OF_USE');

	/**
	 * @see	\wcf\action\IAction::execute()
	 */
	public function execute() {
		parent::execute();

		if (!WCF::getUser()->userID || WCF::getUser()->disclaimerAccepted || TERMS_OF_USE_DECLINEACTION == 'nothing') {
			throw new IllegalLinkException();
		}

		switch (TERMS_OF_USE_DECLINEACTION) {
			case 'disable':
				$langVar = 'wcf.termsOfUse.declined.action.disabled';
				$objectAction = new UserAction(array(WCF::getUser()), 'disable');
				break;
			case 'ban':
				$langVar = 'wcf.termsOfUse.declined.action.banned';
				$objectAction = new UserAction(array(WCF::getUser()), 'ban', array('banReason' => WCF::getLanguage()->get('wcf.termsOfUse.button.decline.banReason')));
				break;
			case 'delete':
				$langVar = 'wcf.termsOfUse.declined.action.deletion';
				$objectAction = new UserAction(array(WCF::getUser()), 'update', array('data' => array('quitStarted' => TIME_NOW)));
				break;
			default:
				break;
		}

		$objectAction->executeAction();

		HeaderUtil::delayedRedirect(LinkHandler::getInstance()->getLink(), WCF::getLanguage()->get($langVar));
		exit;
	}
}
